type_and_status — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

# type_and_status

Created on Sep 25, 2009

@author: Erik De Rijcke

`camelot.model.type_and_status.` `create_type_3_status_mixin`(status_attribute)

  Create a class that can be subclassed to provide a class that has a type 3 status with methods to manipulate and review its status :param status_attribute: the name of the type 3 status attribute

`camelot.model.type_and_status.` `entity_type`(typable_entity, metadata, collection, verbose_entity_name=None)

  Creates a new type related to the given entity. .. typeable_entity:: A string referring to an entity.

`camelot.model.type_and_status.` `get_status_class`(cls_name)

  Parameters: | cls_name – an Entity class name
  Returns: | the status class used for this entity

`camelot.model.type_and_status.` `get_status_type_class`(cls_name)

  Parameters: | cls_name – an Entity class name
  Returns: | the status type class used for this entity

`camelot.model.type_and_status.` `type_3_status`(statusable_entity, metadata, collection, verbose_entity_name=None, enumeration=None)

  Creates a new type 3 status related to the given entity :statusable_entity: A string referring to an entity. :enumeration: if this parameter is used, no status type Entity is created, but the status type is described by the enumeration.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

Comments
blog comments powered by Disqus